==> php82-nextcloud-28.0.2.tgz: share/nextcloud/apps/text/l10n/ro.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fișierul a fost încărcat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Could not write file to disk" : "Nu s-a putut scrie fișierul pe disc",
    "A PHP extension stopped the file upload" : "O extensie PHP a oprit încărcarea fișierelor",
    "No file uploaded or file size exceeds maximum of %s" : "Niciun fișier pentru încărcare sau s-a depășit maximul de %s",
    "Text" : "Text",
    "Translate" : "Tradu",
    "Use current version" : "Folosește versiunea curentă",
    "Use the saved version" : "Folosește versiuna salvată",
    "Guest" : "Invitat",
    "guest" : "invitat",
    "Offline" : "Offline",
    "Saving …" : "Se salvează",
    "Saved" : "Salvat",
    "Unsaved changes" : "Modificări nesalvate",
    "Formatting help" : "Ajutor pentru formatare",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Quoted text" : "Text citat",
    "Edit link" : "Editare link",
    "Cancel" : "Anulare",
    "URL" : "URL",
    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
    "to" : "către",
    "Replace" : "Înlocuiește",
    "Source code" : "Cod sursă",
    "Undo" : "Anulează ultima acțiune",
    "Redo" : "Repetă",
    "Info" : "Info",
    "Success" : "Succes",
    "Warning" : "Atenție",
    "Formatting" : "Formatare",
    "Edit" : "Editează",
    "Link copied" : "Link copiat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> php82-nextcloud-29.0.7.tgz: share/nextcloud/apps/text/l10n/ro.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Fișierul a fost încărcat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Fișierul încărcat depășește directiva upload_max_filesize din php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Fișierul încărcat depășește directiva MAX_FILE_SIZE specificată în formularul HTML",
    "The file was only partially uploaded" : "Fișierul a fost încărcat doar parțial",
    "No file was uploaded" : "Nu a fost încărcat niciun fișier",
    "Missing a temporary folder" : "Lipsește un dosar temporar",
    "Could not write file to disk" : "Nu s-a putut scrie fișierul pe disc",
    "A PHP extension stopped the file upload" : "O extensie PHP a oprit încărcarea fișierelor",
    "No file uploaded or file size exceeds maximum of %s" : "Niciun fișier pentru încărcare sau s-a depășit maximul de %s",
    "File not found" : "Fișierul nu a fost găsit",
    "Text" : "Text",
    "Translate" : "Tradu",
    "Use current version" : "Folosește versiunea curentă",
    "Use the saved version" : "Folosește versiuna salvată",
    "Reload" : "Reîncarcă",
    "Guest" : "Invitat",
    "Remove link" : "Șterge link-ul",
    "guest" : "invitat",
    "Offline" : "Offline",
    "Saving …" : "Se salvează",
    "Saved" : "Salvat",
    "Unsaved changes" : "Modificări nesalvate",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Quoted text" : "Text citat",
    "Link" : "Legătură",
    "Undo" : "Anulează ultima acțiune",
    "Redo" : "Repetă",
    "Edit link" : "Editare link",
    "Cancel" : "Anulare",
    "URL" : "URL",
    "Cannot copy, please copy the link manually" : "Nu s-a putut copia, vă rugăm să copiați link-ul manual",
    "Formatting help" : "Ajutor pentru formatare",
    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
    "to" : "către",
    "Replace" : "Înlocuiește",
    "Edit" : "Editează",
    "Source code" : "Cod sursă",
    "Info" : "Info",
    "Success" : "Succes",
    "Warning" : "Atenție",
    "Details" : "Detalii",
    "Formatting" : "Formatare"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
